@@ -49,7 +49,7 @@ func (c *deleteCmd) run(config *lxd.Config, args []string) error {
 			return err
 		}
 
-		ct, err := d.ContainerStatus(name, false)
+		ct, err := d.ContainerStatus(name)
 
 		if err != nil {
 			// Could be a snapshot
